;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.5.4" "Operations on the current project" '((emacs "26.1") (xref "1.0.2")) :url "https://elpa.gnu.org/packages/project.html")
